@@ -1,49 +1,45 @@
 from http import HTTPStatus
-from typing import Any, Dict, Optional
+from typing import Any, Dict, List, Optional, Union, cast
 
 import httpx
 
 from ... import errors
-from ...client import Client
-from ...models.post_run_underlying_data_query_json_body import (
-    PostRunUnderlyingDataQueryJsonBody,
-)
-from ...models.post_run_underlying_data_query_response_200 import (
-    PostRunUnderlyingDataQueryResponse200,
-)
-from ...types import Response
+from ...client import AuthenticatedClient, Client
+from ...models.api_run_query_response import ApiRunQueryResponse
+from ...models.metric_query_request import MetricQueryRequest
+from ...types import UNSET, Response
 
 
 def _get_kwargs(
     project_uuid: str,
     explore_id: str,
     *,
-    client: Client,
-    json_body: PostRunUnderlyingDataQueryJsonBody,
+    body: MetricQueryRequest,
 ) -> Dict[str, Any]:
-    url = "{}/api/v1/projects/{projectUuid}/explores/{exploreId}/runUnderlyingDataQuery".format(
-        client.base_url, projectUuid=project_uuid, exploreId=explore_id
-    )
+    headers: Dict[str, Any] = {}
 
-    headers: Dict[str, str] = client.get_headers()
-    cookies: Dict[str, Any] = client.get_cookies()
-
-    json_json_body = json_body.to_dict()
-
-    return {
+    _kwargs: Dict[str, Any] = {
         "method": "post",
-        "url": url,
-        "headers": headers,
-        "cookies": cookies,
-        "timeout": client.get_timeout(),
-        "follow_redirects": client.follow_redirects,
-        "json": json_json_body,
+        "url": "/api/v1/projects/{projectUuid}/explores/{exploreId}/runUnderlyingDataQuery".format(
+            projectUuid=project_uuid,
+            exploreId=explore_id,
+        ),
     }
 
+    _body = body.to_dict()
 
-def _parse_response(*, client: Client, response: httpx.Response) -> Optional[PostRunUnderlyingDataQueryResponse200]:
+    _kwargs["json"] = _body
+    headers["Content-Type"] = "application/json"
+
+    _kwargs["headers"] = headers
+    return _kwargs
+
+
+def _parse_response(
+    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
+) -> Optional[ApiRunQueryResponse]:
     if response.status_code == HTTPStatus.OK:
-        response_200 = PostRunUnderlyingDataQueryResponse200.from_dict(response.json())
+        response_200 = ApiRunQueryResponse.from_dict(response.json())
 
         return response_200
     if client.raise_on_unexpected_status:
@@ -52,7 +48,9 @@ def _parse_response(*, client: Client, response: httpx.Response) -> Optional[Pos
         return None
 
 
-def _build_response(*, client: Client, response: httpx.Response) -> Response[PostRunUnderlyingDataQueryResponse200]:
+def _build_response(
+    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
+) -> Response[ApiRunQueryResponse]:
     return Response(
         status_code=HTTPStatus(response.status_code),
         content=response.content,
@@ -65,33 +63,31 @@ def sync_detailed(
     project_uuid: str,
     explore_id: str,
     *,
-    client: Client,
-    json_body: PostRunUnderlyingDataQueryJsonBody,
-) -> Response[PostRunUnderlyingDataQueryResponse200]:
+    client: Union[AuthenticatedClient, Client],
+    body: MetricQueryRequest,
+) -> Response[ApiRunQueryResponse]:
     """Run a query for underlying data results
 
     Args:
         project_uuid (str):
         explore_id (str):
-        json_body (PostRunUnderlyingDataQueryJsonBody): metricQuery for the chart to run
+        body (MetricQueryRequest):
 
     Raises:
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
     Returns:
-        Response[PostRunUnderlyingDataQueryResponse200]
+        Response[ApiRunQueryResponse]
     """
 
     kwargs = _get_kwargs(
         project_uuid=project_uuid,
         explore_id=explore_id,
-        client=client,
-        json_body=json_body,
+        body=body,
     )
 
-    response = httpx.request(
-        verify=client.verify_ssl,
+    response = client.get_httpx_client().request(
         **kwargs,
     )
 
@@ -102,29 +98,29 @@ def sync(
     project_uuid: str,
     explore_id: str,
     *,
-    client: Client,
-    json_body: PostRunUnderlyingDataQueryJsonBody,
-) -> Optional[PostRunUnderlyingDataQueryResponse200]:
+    client: Union[AuthenticatedClient, Client],
+    body: MetricQueryRequest,
+) -> Optional[ApiRunQueryResponse]:
     """Run a query for underlying data results
 
     Args:
         project_uuid (str):
         explore_id (str):
-        json_body (PostRunUnderlyingDataQueryJsonBody): metricQuery for the chart to run
+        body (MetricQueryRequest):
 
     Raises:
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
     Returns:
-        PostRunUnderlyingDataQueryResponse200
+        ApiRunQueryResponse
     """
 
     return sync_detailed(
         project_uuid=project_uuid,
         explore_id=explore_id,
         client=client,
-        json_body=json_body,
+        body=body,
     ).parsed
 
 
@@ -132,33 +128,31 @@ async def asyncio_detailed(
     project_uuid: str,
     explore_id: str,
     *,
-    client: Client,
-    json_body: PostRunUnderlyingDataQueryJsonBody,
-) -> Response[PostRunUnderlyingDataQueryResponse200]:
+    client: Union[AuthenticatedClient, Client],
+    body: MetricQueryRequest,
+) -> Response[ApiRunQueryResponse]:
     """Run a query for underlying data results
 
     Args:
         project_uuid (str):
         explore_id (str):
-        json_body (PostRunUnderlyingDataQueryJsonBody): metricQuery for the chart to run
+        body (MetricQueryRequest):
 
     Raises:
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
     Returns:
-        Response[PostRunUnderlyingDataQueryResponse200]
+        Response[ApiRunQueryResponse]
     """
 
     kwargs = _get_kwargs(
         project_uuid=project_uuid,
         explore_id=explore_id,
-        client=client,
-        json_body=json_body,
+        body=body,
     )
 
-    async with httpx.AsyncClient(verify=client.verify_ssl) as _client:
-        response = await _client.request(**kwargs)
+    response = await client.get_async_httpx_client().request(**kwargs)
 
     return _build_response(client=client, response=response)
 
@@ -167,22 +161,22 @@ async def asyncio(
     project_uuid: str,
     explore_id: str,
     *,
-    client: Client,
-    json_body: PostRunUnderlyingDataQueryJsonBody,
-) -> Optional[PostRunUnderlyingDataQueryResponse200]:
+    client: Union[AuthenticatedClient, Client],
+    body: MetricQueryRequest,
+) -> Optional[ApiRunQueryResponse]:
     """Run a query for underlying data results
 
     Args:
         project_uuid (str):
         explore_id (str):
-        json_body (PostRunUnderlyingDataQueryJsonBody): metricQuery for the chart to run
+        body (MetricQueryRequest):
 
     Raises:
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
     Returns:
-        PostRunUnderlyingDataQueryResponse200
+        ApiRunQueryResponse
     """
 
     return (
@@ -190,6 +184,6 @@ async def asyncio(
             project_uuid=project_uuid,
             explore_id=explore_id,
             client=client,
-            json_body=json_body,
+            body=body,
         )
     ).parsed
