@@ -1,38 +1,28 @@
 from http import HTTPStatus
-from typing import Any, Dict, Optional
+from typing import Any, Dict, List, Optional, Union, cast
 
 import httpx
 
 from ... import errors
-from ...client import Client
-from ...models.list_my_available_organizations_response_200 import (
-    ListMyAvailableOrganizationsResponse200,
-)
-from ...types import Response
+from ...client import AuthenticatedClient, Client
+from ...models.api_user_allowed_organizations_response import ApiUserAllowedOrganizationsResponse
+from ...types import UNSET, Response
 
 
-def _get_kwargs(
-    *,
-    client: Client,
-) -> Dict[str, Any]:
-    url = "{}/api/v1/user/me/allowedOrganizations".format(client.base_url)
-
-    headers: Dict[str, str] = client.get_headers()
-    cookies: Dict[str, Any] = client.get_cookies()
-
-    return {
+def _get_kwargs() -> Dict[str, Any]:
+    _kwargs: Dict[str, Any] = {
         "method": "get",
-        "url": url,
-        "headers": headers,
-        "cookies": cookies,
-        "timeout": client.get_timeout(),
-        "follow_redirects": client.follow_redirects,
+        "url": "/api/v1/user/me/allowedOrganizations",
     }
 
+    return _kwargs
 
-def _parse_response(*, client: Client, response: httpx.Response) -> Optional[ListMyAvailableOrganizationsResponse200]:
+
+def _parse_response(
+    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
+) -> Optional[ApiUserAllowedOrganizationsResponse]:
     if response.status_code == HTTPStatus.OK:
-        response_200 = ListMyAvailableOrganizationsResponse200.from_dict(response.json())
+        response_200 = ApiUserAllowedOrganizationsResponse.from_dict(response.json())
 
         return response_200
     if client.raise_on_unexpected_status:
@@ -41,7 +31,9 @@ def _parse_response(*, client: Client, response: httpx.Response) -> Optional[Lis
         return None
 
 
-def _build_response(*, client: Client, response: httpx.Response) -> Response[ListMyAvailableOrganizationsResponse200]:
+def _build_response(
+    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
+) -> Response[ApiUserAllowedOrganizationsResponse]:
     return Response(
         status_code=HTTPStatus(response.status_code),
         content=response.content,
@@ -52,8 +44,8 @@ def _build_response(*, client: Client, response: httpx.Response) -> Response[Lis
 
 def sync_detailed(
     *,
-    client: Client,
-) -> Response[ListMyAvailableOrganizationsResponse200]:
+    client: Union[AuthenticatedClient, Client],
+) -> Response[ApiUserAllowedOrganizationsResponse]:
     """List the organizations that the current user can join.
     This is based on the user's primary email domain and the organization's allowed email domains.
 
@@ -62,15 +54,12 @@ def sync_detailed(
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
     Returns:
-        Response[ListMyAvailableOrganizationsResponse200]
+        Response[ApiUserAllowedOrganizationsResponse]
     """
 
-    kwargs = _get_kwargs(
-        client=client,
-    )
+    kwargs = _get_kwargs()
 
-    response = httpx.request(
-        verify=client.verify_ssl,
+    response = client.get_httpx_client().request(
         **kwargs,
     )
 
@@ -79,8 +68,8 @@ def sync_detailed(
 
 def sync(
     *,
-    client: Client,
-) -> Optional[ListMyAvailableOrganizationsResponse200]:
+    client: Union[AuthenticatedClient, Client],
+) -> Optional[ApiUserAllowedOrganizationsResponse]:
     """List the organizations that the current user can join.
     This is based on the user's primary email domain and the organization's allowed email domains.
 
@@ -89,7 +78,7 @@ def sync(
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
     Returns:
-        ListMyAvailableOrganizationsResponse200
+        ApiUserAllowedOrganizationsResponse
     """
 
     return sync_detailed(
@@ -99,8 +88,8 @@ def sync(
 
 async def asyncio_detailed(
     *,
-    client: Client,
-) -> Response[ListMyAvailableOrganizationsResponse200]:
+    client: Union[AuthenticatedClient, Client],
+) -> Response[ApiUserAllowedOrganizationsResponse]:
     """List the organizations that the current user can join.
     This is based on the user's primary email domain and the organization's allowed email domains.
 
@@ -109,23 +98,20 @@ async def asyncio_detailed(
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
     Returns:
-        Response[ListMyAvailableOrganizationsResponse200]
+        Response[ApiUserAllowedOrganizationsResponse]
     """
 
-    kwargs = _get_kwargs(
-        client=client,
-    )
+    kwargs = _get_kwargs()
 
-    async with httpx.AsyncClient(verify=client.verify_ssl) as _client:
-        response = await _client.request(**kwargs)
+    response = await client.get_async_httpx_client().request(**kwargs)
 
     return _build_response(client=client, response=response)
 
 
 async def asyncio(
     *,
-    client: Client,
-) -> Optional[ListMyAvailableOrganizationsResponse200]:
+    client: Union[AuthenticatedClient, Client],
+) -> Optional[ApiUserAllowedOrganizationsResponse]:
     """List the organizations that the current user can join.
     This is based on the user's primary email domain and the organization's allowed email domains.
 
@@ -134,7 +120,7 @@ async def asyncio(
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
     Returns:
-        ListMyAvailableOrganizationsResponse200
+        ApiUserAllowedOrganizationsResponse
     """
 
     return (
