@@ -1,38 +1,28 @@
 from http import HTTPStatus
-from typing import Any
-from typing import Dict
-from typing import Optional
+from typing import Any, Dict, List, Optional, Union, cast
 
 import httpx
 
 from ... import errors
-from ...client import Client
-from ...models.list_organization_email_domains_response_200 import ListOrganizationEmailDomainsResponse200
-from ...types import Response
+from ...client import AuthenticatedClient, Client
+from ...models.api_organization_allowed_email_domains import ApiOrganizationAllowedEmailDomains
+from ...types import UNSET, Response
 
 
-def _get_kwargs(
-    *,
-    client: Client,
-) -> Dict[str, Any]:
-    url = "{}/api/v1/org/allowedEmailDomains".format(client.base_url)
-
-    headers: Dict[str, str] = client.get_headers()
-    cookies: Dict[str, Any] = client.get_cookies()
-
-    return {
+def _get_kwargs() -> Dict[str, Any]:
+    _kwargs: Dict[str, Any] = {
         "method": "get",
-        "url": url,
-        "headers": headers,
-        "cookies": cookies,
-        "timeout": client.get_timeout(),
-        "follow_redirects": client.follow_redirects,
+        "url": "/api/v1/org/allowedEmailDomains",
     }
 
+    return _kwargs
 
-def _parse_response(*, client: Client, response: httpx.Response) -> Optional[ListOrganizationEmailDomainsResponse200]:
+
+def _parse_response(
+    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
+) -> Optional[ApiOrganizationAllowedEmailDomains]:
     if response.status_code == HTTPStatus.OK:
-        response_200 = ListOrganizationEmailDomainsResponse200.from_dict(response.json())
+        response_200 = ApiOrganizationAllowedEmailDomains.from_dict(response.json())
 
         return response_200
     if client.raise_on_unexpected_status:
@@ -41,7 +31,9 @@ def _parse_response(*, client: Client, response: httpx.Response) -> Optional[Lis
         return None
 
 
-def _build_response(*, client: Client, response: httpx.Response) -> Response[ListOrganizationEmailDomainsResponse200]:
+def _build_response(
+    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
+) -> Response[ApiOrganizationAllowedEmailDomains]:
     return Response(
         status_code=HTTPStatus(response.status_code),
         content=response.content,
@@ -52,8 +44,8 @@ def _build_response(*, client: Client, response: httpx.Response) -> Response[Lis
 
 def sync_detailed(
     *,
-    client: Client,
-) -> Response[ListOrganizationEmailDomainsResponse200]:
+    client: Union[AuthenticatedClient, Client],
+) -> Response[ApiOrganizationAllowedEmailDomains]:
     """Gets the allowed email domains for the current user's organization
 
     Raises:
@@ -61,15 +53,12 @@ def sync_detailed(
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
     Returns:
-        Response[ListOrganizationEmailDomainsResponse200]
+        Response[ApiOrganizationAllowedEmailDomains]
     """
 
-    kwargs = _get_kwargs(
-        client=client,
-    )
+    kwargs = _get_kwargs()
 
-    response = httpx.request(
-        verify=client.verify_ssl,
+    response = client.get_httpx_client().request(
         **kwargs,
     )
 
@@ -78,8 +67,8 @@ def sync_detailed(
 
 def sync(
     *,
-    client: Client,
-) -> Optional[ListOrganizationEmailDomainsResponse200]:
+    client: Union[AuthenticatedClient, Client],
+) -> Optional[ApiOrganizationAllowedEmailDomains]:
     """Gets the allowed email domains for the current user's organization
 
     Raises:
@@ -87,7 +76,7 @@ def sync(
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
     Returns:
-        ListOrganizationEmailDomainsResponse200
+        ApiOrganizationAllowedEmailDomains
     """
 
     return sync_detailed(
@@ -97,8 +86,8 @@ def sync(
 
 async def asyncio_detailed(
     *,
-    client: Client,
-) -> Response[ListOrganizationEmailDomainsResponse200]:
+    client: Union[AuthenticatedClient, Client],
+) -> Response[ApiOrganizationAllowedEmailDomains]:
     """Gets the allowed email domains for the current user's organization
 
     Raises:
@@ -106,23 +95,20 @@ async def asyncio_detailed(
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
     Returns:
-        Response[ListOrganizationEmailDomainsResponse200]
+        Response[ApiOrganizationAllowedEmailDomains]
     """
 
-    kwargs = _get_kwargs(
-        client=client,
-    )
+    kwargs = _get_kwargs()
 
-    async with httpx.AsyncClient(verify=client.verify_ssl) as _client:
-        response = await _client.request(**kwargs)
+    response = await client.get_async_httpx_client().request(**kwargs)
 
     return _build_response(client=client, response=response)
 
 
 async def asyncio(
     *,
-    client: Client,
-) -> Optional[ListOrganizationEmailDomainsResponse200]:
+    client: Union[AuthenticatedClient, Client],
+) -> Optional[ApiOrganizationAllowedEmailDomains]:
     """Gets the allowed email domains for the current user's organization
 
     Raises:
@@ -130,7 +116,7 @@ async def asyncio(
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
     Returns:
-        ListOrganizationEmailDomainsResponse200
+        ApiOrganizationAllowedEmailDomains
     """
 
     return (
