@@ -1,39 +1,32 @@
 from http import HTTPStatus
-from typing import Any, Dict, Optional
+from typing import Any, Dict, List, Optional, Union, cast
 
 import httpx
 
 from ... import errors
-from ...client import Client
-from ...models.get_scheduler_job_status_response_200 import (
-    GetSchedulerJobStatusResponse200,
-)
-from ...types import Response
+from ...client import AuthenticatedClient, Client
+from ...models.api_job_status_response import ApiJobStatusResponse
+from ...types import UNSET, Response
 
 
 def _get_kwargs(
     job_id: str,
-    *,
-    client: Client,
 ) -> Dict[str, Any]:
-    url = "{}/api/v1/schedulers/job/{jobId}/status".format(client.base_url, jobId=job_id)
-
-    headers: Dict[str, str] = client.get_headers()
-    cookies: Dict[str, Any] = client.get_cookies()
-
-    return {
+    _kwargs: Dict[str, Any] = {
         "method": "get",
-        "url": url,
-        "headers": headers,
-        "cookies": cookies,
-        "timeout": client.get_timeout(),
-        "follow_redirects": client.follow_redirects,
+        "url": "/api/v1/schedulers/job/{jobId}/status".format(
+            jobId=job_id,
+        ),
     }
 
+    return _kwargs
 
-def _parse_response(*, client: Client, response: httpx.Response) -> Optional[GetSchedulerJobStatusResponse200]:
+
+def _parse_response(
+    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
+) -> Optional[ApiJobStatusResponse]:
     if response.status_code == HTTPStatus.OK:
-        response_200 = GetSchedulerJobStatusResponse200.from_dict(response.json())
+        response_200 = ApiJobStatusResponse.from_dict(response.json())
 
         return response_200
     if client.raise_on_unexpected_status:
@@ -42,7 +35,9 @@ def _parse_response(*, client: Client, response: httpx.Response) -> Optional[Get
         return None
 
 
-def _build_response(*, client: Client, response: httpx.Response) -> Response[GetSchedulerJobStatusResponse200]:
+def _build_response(
+    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
+) -> Response[ApiJobStatusResponse]:
     return Response(
         status_code=HTTPStatus(response.status_code),
         content=response.content,
@@ -54,8 +49,8 @@ def _build_response(*, client: Client, response: httpx.Response) -> Response[Get
 def sync_detailed(
     job_id: str,
     *,
-    client: Client,
-) -> Response[GetSchedulerJobStatusResponse200]:
+    client: Union[AuthenticatedClient, Client],
+) -> Response[ApiJobStatusResponse]:
     """Get a generic job status
     This method can be used when polling from the frontend
 
@@ -67,16 +62,14 @@ def sync_detailed(
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
     Returns:
-        Response[GetSchedulerJobStatusResponse200]
+        Response[ApiJobStatusResponse]
     """
 
     kwargs = _get_kwargs(
         job_id=job_id,
-        client=client,
     )
 
-    response = httpx.request(
-        verify=client.verify_ssl,
+    response = client.get_httpx_client().request(
         **kwargs,
     )
 
@@ -86,8 +79,8 @@ def sync_detailed(
 def sync(
     job_id: str,
     *,
-    client: Client,
-) -> Optional[GetSchedulerJobStatusResponse200]:
+    client: Union[AuthenticatedClient, Client],
+) -> Optional[ApiJobStatusResponse]:
     """Get a generic job status
     This method can be used when polling from the frontend
 
@@ -99,7 +92,7 @@ def sync(
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
     Returns:
-        GetSchedulerJobStatusResponse200
+        ApiJobStatusResponse
     """
 
     return sync_detailed(
@@ -111,8 +104,8 @@ def sync(
 async def asyncio_detailed(
     job_id: str,
     *,
-    client: Client,
-) -> Response[GetSchedulerJobStatusResponse200]:
+    client: Union[AuthenticatedClient, Client],
+) -> Response[ApiJobStatusResponse]:
     """Get a generic job status
     This method can be used when polling from the frontend
 
@@ -124,16 +117,14 @@ async def asyncio_detailed(
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
     Returns:
-        Response[GetSchedulerJobStatusResponse200]
+        Response[ApiJobStatusResponse]
     """
 
     kwargs = _get_kwargs(
         job_id=job_id,
-        client=client,
     )
 
-    async with httpx.AsyncClient(verify=client.verify_ssl) as _client:
-        response = await _client.request(**kwargs)
+    response = await client.get_async_httpx_client().request(**kwargs)
 
     return _build_response(client=client, response=response)
 
@@ -141,8 +132,8 @@ async def asyncio_detailed(
 async def asyncio(
     job_id: str,
     *,
-    client: Client,
-) -> Optional[GetSchedulerJobStatusResponse200]:
+    client: Union[AuthenticatedClient, Client],
+) -> Optional[ApiJobStatusResponse]:
     """Get a generic job status
     This method can be used when polling from the frontend
 
@@ -154,7 +145,7 @@ async def asyncio(
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
     Returns:
-        GetSchedulerJobStatusResponse200
+        ApiJobStatusResponse
     """
 
     return (
