@@ -1,13 +1,16 @@
 import datetime
-from typing import Any, Dict, List, Type, TypeVar
+from typing import TYPE_CHECKING, Any, BinaryIO, Dict, List, Optional, TextIO, Tuple, Type, TypeVar, cast
 
-import attr
+from attrs import define as _attrs_define
+from attrs import field as _attrs_field
 from dateutil.parser import isoparse
 
+from ..types import UNSET, Unset
+
 T = TypeVar("T", bound="EmailOneTimePassword")
 
 
-@attr.s(auto_attribs=True)
+@_attrs_define
 class EmailOneTimePassword:
     """
     Attributes:
@@ -17,10 +20,11 @@ class EmailOneTimePassword:
 
     number_of_attempts: float
     created_at: datetime.datetime
-    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)
+    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)
 
     def to_dict(self) -> Dict[str, Any]:
         number_of_attempts = self.number_of_attempts
+
         created_at = self.created_at.isoformat()
 
         field_dict: Dict[str, Any] = {}
