@@ -1,11 +1,14 @@
-from typing import Any, Dict, List, Type, TypeVar, cast
+from typing import TYPE_CHECKING, Any, BinaryIO, Dict, List, Optional, TextIO, Tuple, Type, TypeVar, cast
 
-import attr
+from attrs import define as _attrs_define
+from attrs import field as _attrs_field
+
+from ..types import UNSET, Unset
 
 T = TypeVar("T", bound="FilterGroupResponseType1")
 
 
-@attr.s(auto_attribs=True)
+@_attrs_define
 class FilterGroupResponseType1:
     """
     Attributes:
@@ -15,7 +18,7 @@ class FilterGroupResponseType1:
 
     and_: List[Any]
     id: str
-    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)
+    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)
 
     def to_dict(self) -> Dict[str, Any]:
         and_ = self.and_
