@@ -1,13 +1,16 @@
 import datetime
-from typing import Any, Dict, List, Type, TypeVar
+from typing import TYPE_CHECKING, Any, BinaryIO, Dict, List, Optional, TextIO, Tuple, Type, TypeVar, cast
 
-import attr
+from attrs import define as _attrs_define
+from attrs import field as _attrs_field
 from dateutil.parser import isoparse
 
+from ..types import UNSET, Unset
+
 T = TypeVar("T", bound="ScheduledJobs")
 
 
-@attr.s(auto_attribs=True)
+@_attrs_define
 class ScheduledJobs:
     """
     Attributes:
@@ -17,10 +20,11 @@ class ScheduledJobs:
 
     id: str
     date: datetime.datetime
-    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)
+    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)
 
     def to_dict(self) -> Dict[str, Any]:
         id = self.id
+
         date = self.date.isoformat()
 
         field_dict: Dict[str, Any] = {}
